﻿//-----------------------------------------------------------------------------
// Copyright 2013 by VueSoft LLC. All rights reserved.
// http://www.printablecal.com
//-----------------------------------------------------------------------------
//
// Redistribution and use in source and binary forms, with or without 
// modification, are permitted provided that the following conditions are met:
//
// 1. Redistributions of source code must retain the above copyright notice, 
//    this list of conditions and the following disclaimer.
// 
// 2. Redistributions in binary form must reproduce the above copyright notice,
//    this list of conditions and the following disclaimer in the documentation
//    and/or other materials provided with the distribution.
// 
// 3. Neither the name of "PrintableCal" nor the names of its contributors may 
//    be used to endorse or promote products derived from this software without
//    specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
// AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
// ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE 
// LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
// CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
// SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
// INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
// CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
// ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
// POSSIBILITY OF SUCH DAMAGE.
//
//-----------------------------------------------------------------------------
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

using Vuesoft.PrintableCal.Common;
using Vuesoft.PrintableCal.Interfaces;

namespace AccessDbCalendarSource
{
   /// <summary>
   /// This class extends the base ScheduleItem class to support a custom data field that gets appended to the description when
   /// calendars are generated.
   /// </summary>
   public class AccessDbScheduleItem : ScheduleItem
   {
      /// <summary>
      /// Construct provided the calendar data source, title, description, start date/time, end date/time, all-day flag,
      /// location, and custom data values.
      /// </summary>
      /// <param name="owner"></param>
      /// <param name="title"></param>
      /// <param name="description"></param>
      /// <param name="start"></param>
      /// <param name="end"></param>
      /// <param name="allDay"></param>
      /// <param name="location"></param>
      /// <param name="customData"></param>
      public AccessDbScheduleItem(
         ICalendarSource owner,
         string title,
         string description,
         DateTime start,
         DateTime end,
         bool allDay,
         string location,
         string customData) : base(owner)
      {
         this.Title = title;

         StringBuilder sb = new StringBuilder();
         
         if (description.Length > 0)
         {
            sb.AppendLine(description);
         }

         if (customData.Length > 0)
         {
            sb.AppendLine(customData);
         }

         this.Description = sb.ToString();
         this.StartDateTime = start;
         this.EndDateTime = end;
         this.IsAllDay = allDay;
         this.Location = location;
      }
   }
}
